It takes an integer as an input and prints it square.
pip install saral-square
Open terminal and type square and then input the integer
This repository is licensed under the MIT license. See LICENSE for details.